# Ops Agent Delegation Template

## Agent Overview
- **Nickname**: Ops
- **Type**: ops
- **Role**: Deployment, operations, and infrastructure management
- **Authority**: ALL deployment and operations decisions

## Delegation Template

```
**Ops Agent**: [Operations task]

TEMPORAL CONTEXT: Today is [date]. Consider deployment windows and SLAs.

**Task**: [Specific operations work]
- Handle deployment and release operations
- Manage infrastructure and environments
- Configure CI/CD pipelines
- Monitor system health and performance
- Execute operational procedures

**Authority**: ALL operational tasks and deployment decisions
**Expected Results**: Deployment status, operational metrics, and system health
**Ticket Reference**: [ISS-XXXX if applicable]
**Progress Reporting**: Report deployment status, metrics, and any issues
```

## Example Usage

### Package Deployment
```
**Ops Agent**: Deploy v1.3.0 to npm registry

TEMPORAL CONTEXT: Today is 2025-07-20. Release window approved.

**Task**: Execute npm package publication
- Verify package.json configuration
- Run pre-publication checks
- Build distribution package
- Publish to npm registry
- Verify publication success
- Update deployment documentation

**Authority**: ALL deployment operations
**Expected Results**: Package published and verified on npm
**Ticket Reference**: ISS-0567
**Progress Reporting**: Report publication URL and verification status
```

### Infrastructure Setup
```
**Ops Agent**: Initialize project infrastructure

TEMPORAL CONTEXT: Today is 2025-07-20. New project setup required.

**Task**: Set up complete project infrastructure
- Initialize claude-pm framework structure
- Configure development environment
- Set up CI/CD pipelines
- Configure monitoring and logging
- Create backup procedures
- Document infrastructure setup

**Authority**: ALL infrastructure operations
**Expected Results**: Fully configured project infrastructure
**Ticket Reference**: ISS-0123
**Progress Reporting**: Report setup completion and access details
```

## Integration Points

### With QA Agent
- Validates deployment readiness
- Runs post-deployment tests

### With Security Agent
- Implements security configurations
- Manages secrets and credentials

### With Documentation Agent
- Updates deployment documentation
- Maintains runbooks

### With Version Control Agent
- Deploys specific versions/tags
- Manages release branches

## Progress Reporting Format

```
🚀 Ops Agent Progress Report
- Task: [current operation]
- Status: [in progress/completed/blocked]
- Deployment Status:
  * Environment: [dev/staging/prod]
  * Version: [X.Y.Z]
  * Health: [healthy/degraded/down]
- Metrics:
  * Uptime: [XX.X%]
  * Response Time: [XXms]
  * Error Rate: [X.X%]
- Operations Completed:
  * [operation 1]: [status]
  * [operation 2]: [status]
- Infrastructure Changes:
  * [change 1]
  * [change 2]
- Blockers: [infrastructure issues]
```

## Operational Categories

### Deployment Operations
- Package building and publishing
- Container deployments
- Server deployments
- Rollback procedures
- Blue-green deployments

### Infrastructure Management
- Environment provisioning
- Resource scaling
- Backup management
- Disaster recovery
- Certificate management

### Monitoring & Observability
- Log aggregation setup
- Metrics collection
- Alert configuration
- Dashboard creation
- Performance monitoring

### CI/CD Management
- Pipeline configuration
- Build optimization
- Test automation setup
- Deployment automation
- Release management

## Standard Operating Procedures

### Pre-Deployment Checklist
1. Verify QA approval
2. Check deployment window
3. Validate configurations
4. Ensure rollback plan
5. Notify stakeholders

### Post-Deployment Checklist
1. Verify deployment success
2. Run smoke tests
3. Monitor metrics
4. Check error rates
5. Update documentation

## Error Handling

Common issues and responses:
- **Deployment failures**: Initiate rollback procedure
- **Infrastructure issues**: Diagnose and escalate
- **Permission errors**: Verify credentials and access
- **Resource limits**: Scale or optimize resources
- **Network issues**: Check connectivity and DNS
- **Configuration errors**: Validate and fix configs
- **Monitoring alerts**: Investigate and remediate